#
#	RE - Simple regular expression access object.
#	Copyright (C) 2011-2012 Johannes Bauer
#	
#	This file is part of jpycommon.
#
#	jpycommon is free software; you can redistribute it and/or modify
#	it under the terms of the GNU General Public License as published by
#	the Free Software Foundation; this program is ONLY licensed under
#	version 3 of the License, later versions are explicitly excluded.
#
#	jpycommon is distributed in the hope that it will be useful,
#	but WITHOUT ANY WARRANTY; without even the implied warranty of
#	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#	GNU General Public License for more details.
#
#	You should have received a copy of the GNU General Public License
#	along with jpycommon; if not, write to the Free Software
#	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
#	Johannes Bauer <JohannesBauer@gmx.de>
#
#   File UUID ff39582a-8d65-4b72-802a-4889cbca3a29

import re

class RE():
	DECIMAL = "-?[0-9]+"
	FLOAT = DECIMAL + "(?:\.[0-9]*)?"
	HEXADECIMAL = "(?:0[xX])?[0-9a-fA-F]+"
	IP = DECIMAL + "\." + DECIMAL + "\." + DECIMAL + "\." + DECIMAL 
	STRING = "[^ ]+"
	IDENTIFIER = "[a-zA-Z0-9-_]+"
	
	GFLOAT = "(" + FLOAT + ")"
	GDECIMAL = "(" + DECIMAL + ")"
	GHEXADECIMAL = "(?:0[xX])?([0-9a-fA-F]+)"
	GESCQUOTE = '"((?:\\\\"|[^"])*)"'
	GIP = "(" + IP + ")"
	GSTRING = "(" + STRING + ")"
	GIDENTIFIER = "(" + IDENTIFIER + ")"


	def __init__(self, pattern):
		self._re = re.compile(pattern)
		self._result = None

	def search(self, text):
		self._result = self._re.search(text)
		if self._result is None:
			return None
		else:
			return self
	
	def match(self, text):
		self._result = self._re.match(text)
		if self._result is None:
			return None
		else:
			return self

	def getall(self):
		results = [ ]
		for i in range(1, 128):
			try:
				results.append(self._result.group(i))
			except IndexError:
				break
		return results

	def __getitem__(self, index):
		return self._result.group(index)
